@@ -15,6 +15,7 @@
 
 from sahara.api import acl
 from sahara.service.api.v2 import job_types as api
+from sahara.service import validation as v
 import sahara.utils.api as u
 
 
@@ -22,10 +23,14 @@ rest = u.RestV2('job-types', __name__)
 
 
 @rest.get('/job-types')
-@acl.enforce("data-processing:job-types:get_all")
+@acl.enforce("data-processing:job-type:list")
+@v.validate_request_params(['type', 'plugin_name', 'plugin_version'])
 def job_types_get():
     # We want to use flat=False with to_dict() so that
     # the value of each arg is given as a list. This supports
     # filters of the form ?type=Pig&type=Java, etc.
-    return u.render(job_types=api.get_job_types(
-        **u.get_request_args().to_dict(flat=False)))
+    request_args = u.get_request_args().to_dict(flat=False)
+    if 'plugin_version' in request_args:
+        request_args['hadoop_version'] = request_args['plugin_version']
+        del request_args['plugin_version']
+    return u.render(job_types=api.get_job_types(**request_args))
