@@ -29,28 +29,14 @@ SWIFT_URL_SUFFIX = SWIFT_URL_SUFFIX_START + 'sahara'
 
 
 def retrieve_auth_url(endpoint_type="publicURL"):
-    """This function returns auth url v2.0 api.
+    """This function returns auth url v3 api.
 
-    Hadoop Swift library doesn't support keystone v3 api.
     """
-    auth_url = clients_base.retrieve_auth_url(endpoint_type=endpoint_type)
-    info = urlparse.urlparse(auth_url)
+    version_suffix = 'v3'
 
-    if CONF.use_domain_for_proxy_users:
-        url = 'v3/auth'
-    else:
-        url = 'v2.0'
-
-    if info.port:
-        returned_url = '{scheme}://{hostname}:{port}/{url}/'
-        return returned_url.format(scheme=info.scheme,
-                                   hostname=info.hostname,
-                                   port=info.port,
-                                   url=url)
-    else:
-        return '{scheme}://{hostname}/{url}/'.format(scheme=info.scheme,
-                                                     hostname=info.hostname,
-                                                     url=url)
+    # return auth url with trailing slash
+    return clients_base.retrieve_auth_url(
+        endpoint_type=endpoint_type, version=version_suffix) + "/"
 
 
 def inject_swift_url_suffix(url):
