@@ -13,9 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
 
-import mock
+from unittest import mock
+
+from oslo_utils import uuidutils
 import testtools
 
 from sahara import exceptions as exc
@@ -108,7 +109,8 @@ class FakeNodeGroup(object):
         self.floating_ip_pool = pool
         self.flavor_id = flavor_id
         self.open_ports = ports
-        self.id = uuid.uuid4()
+        self.id = uuidutils.generate_uuid()
+
 
 nova_limits = {
     'absolute': {
@@ -198,7 +200,6 @@ class TestQuotas(base.SaharaTestCase):
         type(ng).open_ports = mock.PropertyMock(return_value=[1111, 2222])
 
         limits = quotas._get_zero_limits()
-        self.override_config('use_neutron', True)
         quotas._update_limits_for_ng(limits, ng, 3)
 
         self.assertEqual(3, limits['instances'])
@@ -211,21 +212,9 @@ class TestQuotas(base.SaharaTestCase):
         self.assertEqual(5, limits['security_group_rules'])
         self.assertEqual(3, limits['ports'])
 
-        type(ng).open_ports = mock.PropertyMock(return_value=[1, 2, 3])
-        self.override_config('use_neutron', False)
-        quotas._update_limits_for_ng(limits, ng, 3)
-
-        self.assertEqual(6, limits['security_group_rules'])
-        self.assertEqual(3, limits['ports'])
-
     @mock.patch('sahara.utils.openstack.nova.client',
                 return_value=FakeNovaClient(nova_limits))
     def test_get_nova_limits(self, nova):
-        self.assertEqual(
-            {'cpu': 10, 'floatingips': 200,
-             'instances': 3, 'ram': 9, 'security_group_rules': 'unlimited',
-             'security_groups': 28}, quotas._get_nova_limits())
-        self.override_config('use_neutron', True)
         self.assertEqual(
             {'cpu': 10, 'instances': 3, 'ram': 9}, quotas._get_nova_limits())
 
@@ -238,21 +227,21 @@ class TestQuotas(base.SaharaTestCase):
     @mock.patch('sahara.utils.openstack.neutron.client',
                 return_value=FakeNeutronClient(neutron_limits))
     def test_neutron_limits(self, neutron):
-        self.assertEqual({}, quotas._get_neutron_limits())
-        self.override_config('use_neutron', True)
         self.assertEqual({'floatingips': 2340,
                           'ports': 'unlimited',
                           'security_group_rules': 332,
                           'security_groups': 1516},
                          quotas._get_neutron_limits())
 
+    @mock.patch("sahara.utils.openstack.cinder.check_cinder_exists",
+                return_value=True)
     @mock.patch('sahara.utils.openstack.nova.client',
                 return_value=FakeNovaClient(nova_limits))
     @mock.patch('sahara.utils.openstack.cinder.client',
                 return_value=FakeCinderClient(cinder_limits))
     @mock.patch('sahara.utils.openstack.neutron.client',
                 return_value=FakeNeutronClient(neutron_limits))
-    def test_limits_for_cluster(self, p1, p2, p3):
+    def test_limits_for_cluster(self, p1, p2, p3, p4):
         ng = [FakeNodeGroup(1, False, 0, 0, None, 'id1', [1, 2, 3])]
         quotas.check_cluster(FakeCluster(ng))
 
