@@ -13,9 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from cinderclient.v1 import volumes as vol_v1
-from cinderclient.v2 import volumes as vol_v2
-import mock
+from unittest import mock
+
+from cinderclient.v3 import volumes as vol_v3
 
 from sahara import exceptions as ex
 from sahara.service import volumes
@@ -40,10 +40,10 @@ class TestAttachVolume(base.SaharaWithDbTestCase):
                           instance, '123', '456', False)
 
     @mock.patch('sahara.conductor.manager.ConductorManager.cluster_get')
-    @mock.patch('cinderclient.v1.volumes.Volume.delete')
-    @mock.patch('cinderclient.v1.volumes.Volume.detach')
+    @mock.patch('cinderclient.v3.volumes.Volume.delete')
+    @mock.patch('cinderclient.v3.volumes.Volume.detach')
     @mock.patch('sahara.utils.openstack.cinder.get_volume')
-    def test_detach_volumes(self, p_get_volume, p_detach, p_delete, p_cond):
+    def test_detach_volumes_v3(self, p_get_volume, p_detach, p_delete, p_cond):
         class Instance(object):
             def __init__(self):
                 self.instance_id = '123454321'
@@ -51,26 +51,7 @@ class TestAttachVolume(base.SaharaWithDbTestCase):
                 self.instance_name = 'spam'
 
         instance = Instance()
-        p_get_volume.return_value = vol_v1.Volume(None, {'id': '123', 'status':
-                                                         'available'})
-        p_detach.return_value = None
-        p_delete.return_value = None
-        self.assertIsNone(
-            volumes.detach_from_instance(instance))
-
-    @mock.patch('sahara.conductor.manager.ConductorManager.cluster_get')
-    @mock.patch('cinderclient.v2.volumes.Volume.delete')
-    @mock.patch('cinderclient.v2.volumes.Volume.detach')
-    @mock.patch('sahara.utils.openstack.cinder.get_volume')
-    def test_detach_volumes_v2(self, p_get_volume, p_detach, p_delete, p_cond):
-        class Instance(object):
-            def __init__(self):
-                self.instance_id = '123454321'
-                self.volumes = [123]
-                self.instance_name = 'spam'
-
-        instance = Instance()
-        p_get_volume.return_value = vol_v2.Volume(None, {'id': '123', 'status':
+        p_get_volume.return_value = vol_v3.Volume(None, {'id': '123', 'status':
                                                          'available'})
         p_detach.return_value = None
         p_delete.return_value = None
@@ -146,3 +127,27 @@ class TestAttachVolume(base.SaharaWithDbTestCase):
 
         diff = volumes._find_instance_devices(instance)
         self.assertEqual([], diff)
+
+        attached_info = '/dev/vda /dev/nbd1'
+        mounted_info = '/dev/nbd1'
+        ex_cmd.side_effect = [(0, attached_info), (0, mounted_info),
+                              (2, ""), (2, "")]
+
+        diff = volumes._find_instance_devices(instance)
+        self.assertEqual(['/dev/vda'], diff)
+
+        attached_info = '/dev/nbd1 /dev/nbd2'
+        mounted_info = '/dev/nbd1'
+        ex_cmd.side_effect = [(0, attached_info), (0, mounted_info),
+                              (2, ""), (2, "")]
+
+        diff = volumes._find_instance_devices(instance)
+        self.assertEqual(['/dev/nbd2'], diff)
+
+        attached_info = '/dev/nbd1 /dev/nbd2'
+        mounted_info = '/dev/nbd1'
+        ex_cmd.side_effect = [(0, attached_info), (0, mounted_info),
+                              (0, "/dev/nbd2")]
+
+        diff = volumes._find_instance_devices(instance)
+        self.assertEqual([], diff)
